@@ -1,10 +1,12 @@
 import os
 import sys
 from contextlib import contextmanager
+from datetime import datetime
 from glob import iglob
-from typing import List
+from pathlib import Path
+from typing import List, Union
 
-__all__ = ('get_py_files', 'get_file_name', 'temp_syspath')
+__all__ = ('get_py_files', 'get_file_name', 'temp_syspath', 'format_datetime')
 
 
 def get_py_files(path: str) -> List[str]:
@@ -12,17 +14,24 @@ def get_py_files(path: str) -> List[str]:
     yield from iglob(os.path.join(path, '*.py'))
 
 
+def format_datetime(dt: datetime) -> str:
+    return dt.strftime('%d/%m/%Y %H:%M:%S')
+
+
 def get_file_name(path: str):
     """gets the files name without the extension"""
     return os.path.basename(path).split('.')[0]
 
 
 @contextmanager
-def temp_syspath(fullpath):
+def temp_syspath(fullpath: Union[str, Path]):
     """
     temporarily appends the fullpath to sys.path, yields, then removes it from sys.path
     if the fullpath is already in sys.path the append/remove is skipped
     """
+    if isinstance(fullpath, Path):
+        fullpath = str(fullpath)
+
     if not os.path.isabs(fullpath):
         fullpath = os.path.abspath(fullpath)
 
